@@ -403,12 +403,11 @@ class Model:
         self.generate_group_values(df)
         X = df[self.features].values.astype(float)
         sl = ~np.any(np.isnan(X), axis=1)
-        # print(sl.sum(), sl)
 
         Y = np.empty(len(X))
         Y[:] = np.nan
 
-        if sl.sum()<len(X):
+        if sl.sum()>0: #sl.sum()<=len(X) and
 
             Xpr, _ = self.scale(X[sl])
             #Xpr[Xpr<0] = 0 # if new data out of training range
